Welcome to PyTable’s documentation! — PyTables 3.1.1 documentation

### Navigation

- index
- modules
- modules
- next
- PyTables 3.1.1 documentation »

# Welcome to PyTable’s documentation!

PyTables is a package for managing hierarchical datasets and designed to efficiently and easily cope with extremely large amounts of data. You can download PyTables and use it for free. You can access documentation, some examples of use and presentations here.

PyTables is built on top of the HDF5 library, using the Python language and the NumPy package. It features an object-oriented interface that, combined with C extensions for the performance-critical parts of the code (generated using Cython), makes it a fast, yet extremely easy to use tool for interactively browse, process and search very large amounts of data. One important feature of PyTables is that it optimizes memory and disk resources so that data takes much less space (specially if on-flight compression is used) than other solutions such as relational or object oriented databases.

You can also, find more information by reading the PyTables FAQ.

PyTables development is a continuing effort and we are always looking for more developers, testers, and users. If you are interested in being involved with this project, please contact us via github or the mailing list.

## Contents

- User’s Guide
- Cookbook
- FAQ
- Other Material
- Migrating from 2.x to 3.x
- Downloads
- Release Notes
- Project pointers
- Development
- Development Team

# Helpful Links

- Index
- Search Page

### Navigation

- index
- modules
- modules
- next
- PyTables 3.1.1 documentation »